TwilioConversationsClient class

Inheritance
Annotations
  • @JS.new('Twilio.Conversations.Client')

Constructors

TwilioConversationsClient(String token)
factory

Properties

connectionState ↔ ConnectionState
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reachabilityEnabled ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → TwilioConversationsUser
no setter
version → String
no setter

Methods

getConversationBySid(String conversationSid) → TwilioConversationsChannel
getConversationByUniqueName(String UniqueName) → dynamic
getSubscribedConversations() → JSPaginator<TwilioConversationsChannel>
getSubscribedUsers() → dynamic
getUser(String identity) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String eventName, Function listener) → dynamic
inherited
on(String eventName, Function listener) → dynamic
inherited
removePushRegistrations(String channelType, String registrationId) → dynamic
setPushRegistrationId(String channelType, String registrationId) → dynamic
shutdown() → dynamic
toString() → String
A string representation of this object.
inherited
updateToken(String token) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited