TwilioConversationsMessage class

Annotations
  • @JS.new('Twilio.Conversations.Message')

Properties

attachedMedia ↔ List<TwilioConversationsMedia>
getter/setter pair
attributes ↔ JSMap
getter/setter pair
author ↔ String
getter/setter pair
body ↔ String
getter/setter pair
channelSid ↔ String
getter/setter pair
conversation ↔ TwilioConversationsChannel
getter/setter pair
dateCreated ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
participantSid ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sid ↔ String
getter/setter pair
updated → dynamic
no setter

Methods

getParticipant() → TwilioConversationsMember
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited