MessageBuilder class

Annotations
  • @JS.new('Twilio.Conversations.MessageBuilder')

Constructors

MessageBuilder()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMedia(FormData media) → MessageBuilder
build() → UnsentMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributes(JSMap attributes) → MessageBuilder
setBody(String body) → MessageBuilder
toString() → String
A string representation of this object.
inherited
withOptions(JSMap options) → MessageBuilder

Operators

operator ==(Object other) → bool
The equality operator.
inherited