PushNotification class

Annotations
  • @JS.new('Twilio.Conversations.PushNotification')

Constructors

PushNotification()

Properties

action ↔ String?
getter/setter pair
badge ↔ int?
getter/setter pair
body ↔ String?
getter/setter pair
data ↔ PushNotificationData?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sound ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ String?
"twilio.conversations.new_message" | "twilio.conversations.added_to_conversation" | "twilio.conversations.removed_from_conversation"
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited