TwilioConversationsUser class

Annotations
  • @JS.new('Twilio.Conversations.User')

Constructors

TwilioConversationsUser()
factory

Properties

attributes → Attributes?
no setter
friendlyName → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
identity → String
no setter
isNotifiable → bool?
no setter
isOnline → bool?
no setter
isSubscribed → bool?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited