JSMap<K, V> class

Available extensions
Annotations
  • @JS.new('Map')

Constructors

JSMap()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter

Methods

entries() → JSIterator<List>
Returns an JSIterator of all the key value pairs in the Map
keys() → JSIterator<K>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDartMap() → Map<K, V>

Available on JSMap<K, V>, provided by the Interop extension

toString() → String
A string representation of this object.
inherited
values() → JSIterator<V>

Operators

operator ==(Object other) → bool
The equality operator.
inherited