NotificationsMethods class

Constructors

NotificationsMethods()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerForNotification(TwilioConversationsClient? chatClient, {required String channel, required String token}) → Future<void>
toString() → String
A string representation of this object.
inherited
unregisterForNotification(TwilioConversationsClient? chatClient, {required String channel, required String token}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited